# Craftbeerpi4 PushOver Notifications Plugin

## Plugin to forward Craftbeerpi4 Notifications to Pushover Push Notification service

###Installation:

- pip isntal cbpi4-PushOver
-> or installation from github

cbpi add cbpi4-PushOver

###Usage:

- First Installation will add parameters to settings.
- Configure settings by adding token and user.
- Restart cbpi

###Parameters:

- pushover_token: your token for this service
- pushover_user: your user for this service

###Changelog:
15.03.21: Initial Release.
